.. pyauditor documentation master file, created by
   sphinx-quickstart on Thu Aug 11 15:26:35 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyauditor's documentation!
=====================================


pyauditor is a client for interacting with an Auditor instance via Python.
It provides functionality to create records and send records to and receive records from Auditor and as such serves as the basic building block for `Collectors` and `Plugins` written in Python.


Installation
============

pyauditor requires a Python version >= 3.7.

.. code-block::

    python3 -m pip install python-auditor




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Contents:

   Introduction <self>
   examples
   api
   changelog
